/* giFTcurs - curses interface to giFT
 * Copyright (C) 2001, 2002, 2003 Gran Weinholt <weinholt@dtek.chalmers.se>
 * Copyright (C) 2003 Christian Hggstrm <chm@c00.info>
 *
 * This file is part of giFTcurs.
 *
 * giFTcurs is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * giFTcurs is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with giFTcurs; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,  USA.
 *
 * $Id: format.h,v 1.10 2003/04/03 20:50:55 chnix Exp $
 */
#ifndef _FORMAT_H
#define _FORMAT_H

typedef struct precompiled *format_t;

/* This describes how to get meta data from an object.
 * The return values of the different meta data types are:
 *  nul-terminated string: return string;
 * constant length string: *intval = length, return string;
 *       unsigned integer: *intval = integer, return NULL;
 *       non-existent key: return "";
 */
typedef char *(*getattrF) (const void *udata, char *key, unsigned int *intval);

/* This function takes a string, parses it and returns a linked list of
 * atoms. If an error occurs, A message is printed, and NULL is returned. */
format_t format_compile(char *src);

/* Copies a compiled format */
format_t format_ref(format_t n);

/* Frees a compiled format */
void format_unref(format_t n);

/* Define a macro */
format_t format_load(char *id, char *standard);

/* Fetch and reference a macro */
format_t format_get(char *id, char *standard);

#include "list.h"

/* sorts according to a format string */
int make_sortkey(char **res, const void *item, char *format, getattrF getattr);

/* Formats a hit according to a format and a width */
char *format_expand(format_t format, getattrF, int maxlen, void *udata);

/* returns the free disk space in giFT download directory or -1 */
unsigned int disk_free_kb(void);

/* free some memory allocated by macros */
void format_clear(void);

#endif
