/* giFTcurs - curses interface to giFT
 * Copyright (C) 2001, 2002, 2003 Gran Weinholt <weinholt@dtek.chalmers.se>
 * Copyright (C) 2003 Christian Hggstrm <chm@c00.info>
 *
 * This file is part of giFTcurs.
 *
 * giFTcurs is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * giFTcurs is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with giFTcurs; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,  USA.
 *
 * $Id: transfer.h,v 1.45 2003/04/14 18:54:19 chnix Exp $
 */
#ifndef _TRANSFER_H
#define _TRANSFER_H

#include "parse.h"
#include "tree.h"
#include "gift.h"

enum {
	TRANSFER_UPLOAD,
	TRANSFER_DOWNLOAD
};

/* struct that keeps track of the latest changes in bandwidth */
struct bandwidth_meas {
	struct {
		int dt;
		int dsize;
	} samples[5];				/* approx. seconds to take average on */
	unsigned int bandwidth;
};

typedef struct {
	tree_node tnode;
	char *user;
	char *node;
	char *href;
	unsigned int start;
	unsigned int transmit;
	unsigned int total;
	char *status;
	struct bandwidth_meas bw;
} source;

typedef struct _transfer_t {
	tree_node tnode;
	gift_id id;
	char *filename;
	char *protocol;
	unsigned int filesize, transferred;
	unsigned int last_time;
	char *hash;
	char *status;
	unsigned int elapsed;		/* Time elapsed between last updates */
	struct bandwidth_meas bw;

	unsigned paused:1;
	unsigned autodestroy:1;
	unsigned type:1;
	unsigned kilobyte_mode:1;	/* filesize and transferred is kB */

	/* Download specific variables */
	gift_id search_id;			/* id receiving search results from giFT */
} transfer;

void source_cancel(transfer * t, source * s);
void source_destroy(source *);
void source_touch(source *);

void transfers_init(void);

transfer *transfer_find(tree *, char *hash, unsigned int size, int deadness);
source *lookup_source(transfer * t, const char *user, const char *href);
void transfer_destroy(transfer *);
void transfer_touch(transfer *);
void transfer_detach(transfer *);
void transfer_cancel(transfer *);
void transfer_forget(transfer *);
void transfer_reset(transfer *);
void transfer_suspend(transfer *);
int transfers_calculate(void);

extern int autodestroy_all;
extern rendering transfer_methods, source_methods;
extern tree downloads, uploads;

int transfer_alive(transfer *);
char *transfer_change_sort_method(tree * active_tree, int dir);

#endif
